pub struct MountedDir { /* private fields */ }Expand description
A live Table/Dir namespace assembled from a root Dir and explicit mounts.
Implementations
Sourceimpl MountedDir
impl MountedDir
Sourcepub fn new(root: Value) -> Result<Self>
pub fn new(root: Value) -> Result<Self>
Create a mounted namespace rooted at root.
root must be a directory value. The namespace starts with no mounts.
Sourcepub fn mount_dir(
&self,
cx: &mut Cx,
path: TablePath,
target: Value,
) -> Result<()>
pub fn mount_dir( &self, cx: &mut Cx, path: TablePath, target: Value, ) -> Result<()>
Mount target as a directory at absolute path.
Sourcepub fn mount_table(
&self,
cx: &mut Cx,
path: TablePath,
target: Value,
) -> Result<()>
pub fn mount_table( &self, cx: &mut Cx, path: TablePath, target: Value, ) -> Result<()>
Mount target as a table leaf at absolute path.
Sourcepub fn unmount(&self, cx: &mut Cx, path: &TablePath) -> Result<Option<Value>>
pub fn unmount(&self, cx: &mut Cx, path: &TablePath) -> Result<Option<Value>>
Remove the exact mount at absolute path.
Sourcepub fn inspect(&self) -> Result<Vec<MountInspection>>
pub fn inspect(&self) -> Result<Vec<MountInspection>>
Return the current mount table as absolute paths and target kinds.